@@ -63,6 +63,8 @@
 
 /*
  * watchdog state
+ * If you add a new state. Remember to add entry in
+ * wd_state_names (watchdog.c)
  */
 typedef enum {
 	WD_DEAD = 0,
@@ -91,6 +93,10 @@ typedef enum {
 	WD_SOCK_CLOSED
 } WD_SOCK_STATE;
 
+/*
+ * If you add a new event. Remember to add entry in
+ * wd_event_name (watchdog.c)
+ */
 typedef enum {
 	WD_EVENT_WD_STATE_CHANGED = 0,
 	WD_EVENT_TIMEOUT,
@@ -117,8 +123,12 @@ typedef enum {
 	WD_EVENT_I_AM_APPEARING_FOUND
 }			WD_EVENTS;
 
+/*
+ * If you add a new lost reason. Remember to add entry in
+ * wd_node_lost_reasons (watchdog.c)
+ */
 typedef enum {
-	NODE_LOST_UNKNOWN_REASON,
+	NODE_LOST_UNKNOWN_REASON = 0,
 	NODE_LOST_BY_LIFECHECK,
 	NODE_LOST_BY_SEND_FAILURE,
 	NODE_LOST_BY_MISSING_BEACON,
